import sys
import os
import subprocess


def launch_game(session_id: str, account) -> None:
    """
    Запускает игру с заданной сессией и информацией об аккаунте.

    Параметры:
      session_id (str): идентификатор сессии.
      account: объект с атрибутами account_id и display_name.
             Например, экземпляр класса Account с соответствующими полями.
    """
    # Получаем путь к игре из переменной окружения, если она не задана, используем значение по умолчанию.
    # game = os.getenv("PYSCAPE_GAME_PATH", "/home/fz0x1/projects/pyscape/RuneLite.jar")
    game = os.getenv(
        "PYSCAPE_GAME_PATH", "/home/fz0x1/projects/pyscape/RuneLiteClean.jar"
    )

    # Копируем текущее окружение и добавляем дополнительные переменные
    env = os.environ.copy()
    env.update(
        {
            "JX_SESSION_ID": session_id,
            "JX_CHARACTER_ID": account.account_id,
            "JX_DISPLAY_NAME": account.display_name,
        }
    )
    if game.endswith(".jar"):
        subprocess.Popen(
            ["java", "-jar", game],
            env=env,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL,
        )
    else:
        subprocess.Popen([game], env=env)

    sys.exit(1)
